%global selinuxtype targeted
%global moduletype contrib
%define semodule_version 0.0.4

Summary:          A tool for implementing USB device usage policy
Name:             usbguard
Version:          1.1.2
Release:          7%{?dist}
License:          GPLv2+
URL:              https://usbguard.github.io/
Source0:          https://github.com/USBGuard/usbguard/releases/download/%{name}-%{version}/%{name}-%{version}.tar.gz
Source1:          https://github.com/USBGuard/usbguard-selinux/archive/refs/tags/v%{semodule_version}.tar.gz
Source2:          usbguard-daemon.conf

Patch3000:        usbguard-revert-catch.patch
Patch3001:        policykit-dbus-chat-selinux.patch

BuildRequires:    make gcc gcc-c++ autoconf automake libtool
BuildRequires:    libqb-devel libgcrypt-devel libstdc++-devel protobuf-devel protobuf-compiler
BuildRequires:    PEGTL-static catch1-devel bash-completion asciidoc audit-libs-devel systemd

Requires:         (%{name}-selinux if selinux-policy-%{selinuxtype})
Requires:         systemd
Requires(post):   systemd
Requires(preun):  systemd
Requires(postun): systemd
Requires(post):   /sbin/ldconfig
Requires(postun): /sbin/ldconfig

%description
The USBGuard software framework helps to protect your computer against rogue USB
devices by implementing basic whitelisting/blacklisting capabilities based on
USB device attributes.


%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}
Requires:       pkgconfig
Requires:       libstdc++-devel

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%package        tools
Summary:        USBGuard Tools
Requires:       %{name} = %{version}-%{release}

%description    tools
The %{name}-tools package contains optional tools from the USBGuard
software framework.


%package        dbus
Summary:        USBGuard D-Bus Service
Requires:       %{name} = %{version}-%{release}
BuildRequires:	glib2-devel
BuildRequires:	dbus-glib-devel dbus-devel polkit-devel libxslt libxml2
Requires:       dbus polkit

%description    dbus
The %{name}-dbus package contains an optional component that provides
a D-Bus interface to the USBGuard daemon component.


%package        selinux
Summary:        USBGuard selinux
Group:          Applications/System
Requires:       %{name} = %{version}-%{release}
Requires:       selinux-policy-%{selinuxtype}
Requires(post): selinux-policy-%{selinuxtype}
BuildRequires:  selinux-policy-devel
BuildArch: noarch
%{?selinux_requires}

%description    selinux
The %{name}-selinux package contains selinux policy for the USBGuard
daemon.


%prep
%autosetup -a 1 -p1
rm -rf src/ThirdParty/{Catch,PEGTL}


%build
mkdir -p ./m4
autoreconf -iv --no-recursive ./
%configure \
    --disable-silent-rules \
    --without-bundled-catch \
    --without-bundled-pegtl \
    --enable-systemd \
    --with-dbus \
    --with-polkit \
    --with-crypto-library=gcrypt

%make_build

pushd %{name}-selinux-%{semodule_version}
make
popd


%install
%make_install

mkdir -p %{buildroot}%{_sysconfdir}/usbguard
mkdir -p %{buildroot}%{_sysconfdir}/usbguard/rules.d
mkdir -p %{buildroot}%{_sysconfdir}/usbguard/IPCAccessControl.d
install -p -m 644 usbguard-daemon.conf.in %{buildroot}%{_sysconfdir}/usbguard/usbguard-daemon.conf

install -d %{buildroot}%{_datadir}/selinux/packages/%{selinuxtype}
install -m 0644 %{name}-selinux-%{semodule_version}/%{name}.pp.bz2 %{buildroot}%{_datadir}/selinux/packages/%{selinuxtype}
install -d -p %{buildroot}%{_datadir}/selinux/devel/include/%{moduletype}
install -p -m 644 %{name}-selinux-%{semodule_version}/%{name}.if %{buildroot}%{_datadir}/selinux/devel/include/%{moduletype}/ipp-%{name}.if

find %{buildroot} \( -name '*.la' -o -name '*.a' \) -delete


%check
%make_build check


%preun
%systemd_preun usbguard.service

%post
%systemd_post usbguard.service

%postun
%systemd_postun usbguard.service

%preun dbus
%systemd_preun usbguard-dbus.service

%post dbus
%systemd_post usbguard-dbus.service

%postun dbus
%systemd_postun_with_restart usbguard-dbus.service

%pre selinux
%selinux_relabel_pre -s %{selinuxtype}

%post selinux
%selinux_modules_install -s %{selinuxtype} %{_datadir}/selinux/packages/%{selinuxtype}/%{name}.pp.bz2

%postun selinux
if [ $1 -eq 0 ]; then
    %selinux_modules_uninstall -s %{selinuxtype} %{name}
fi

%posttrans selinux
%selinux_relabel_post -s %{selinuxtype}


%files
%license LICENSE
%doc README.adoc CHANGELOG.md
%{_bindir}/usbguard
%{_libdir}/*.so.*
%{_sbindir}/usbguard-daemon
%dir %{_localstatedir}/log/usbguard
%dir %{_sysconfdir}/usbguard
%dir %{_sysconfdir}/usbguard/rules.d/
%dir %{_sysconfdir}/usbguard/IPCAccessControl.d
%config(noreplace) %attr(0600,-,-) %{_sysconfdir}/usbguard/usbguard-daemon.conf
%config(noreplace) %attr(0600,-,-) %{_sysconfdir}/usbguard/rules.conf
%{_unitdir}/usbguard.service
%{_datadir}/bash-completion/completions/usbguard
%{_datadir}/man/man8/usbguard-daemon.8.gz
%{_datadir}/man/man5/usbguard-daemon.conf.5.gz
%{_datadir}/man/man5/usbguard-rules.conf.5.gz
%{_datadir}/man/man1/usbguard.1.gz

%files devel
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files tools
%{_bindir}/usbguard-rule-parser

%files dbus
%{_sbindir}/usbguard-dbus
%{_datadir}/dbus-1/system-services/org.usbguard1.service
%{_datadir}/dbus-1/system.d/org.usbguard1.conf
%{_datadir}/polkit-1/actions/org.usbguard1.policy
%{_unitdir}/usbguard-dbus.service
%{_mandir}/man8/usbguard-dbus.8.gz

%files selinux
%{_datadir}/selinux/packages/%{selinuxtype}/%{name}.pp.bz2
%ghost %verify(not md5 size mode mtime) %{_sharedstatedir}/selinux/%{selinuxtype}/active/modules/200/%{name}
%{_datadir}/selinux/devel/include/%{moduletype}/ipp-%{name}.if


%changelog
* Fri Dec 22 2023 luffyluo <luffyluo@tencent.com> - 1.1.2-7
- Rebuilt for PEGTL 3.2.7

* Tue Sep 19 2023 Miaojun Dong <zoedong@tencent.com> - 1.1.2-6
- Rebuild for protobuf-24.2

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.1.2-5
- Rebuilt for OpenCloudOS Stream 23.09

* Thu Sep 07 2023 cunshunxia@tencent.com - 1.1.2-4
- Rebuilt for protobuf 3.21.12

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.1.2-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.1.2-2
- Rebuilt for OpenCloudOS Stream 23

* Tue Mar 21 2023 Miaojun Dong <zoedong@tencent.com> - 1.1.0-1
- initial build
